complete -c paccat -s r -l root -d 'Set an alternative root directory' -r
complete -c paccat -s b -l dbpath -d 'Set an alternative database location' -r
complete -c paccat -l config -d 'Use an alternative pacman.conf' -r
complete -c paccat -l color -d 'Specify when to enable coloring' -r -f -a "auto\t''
always\t''
never\t''"
complete -c paccat -l cachedir -d 'Set the primary cache directory' -r
complete -c paccat -s F -l files -d 'Use files database to search for files before downloading'
complete -c paccat -s Q -l query -d 'Use local database to search for files before downloading'
complete -c paccat -s y -l refresh -d 'Download fresh package databases from the server'
complete -c paccat -s a -l all -d 'Print all matching files instead of just the first'
complete -c paccat -s x -l regex -d 'Enable searching using regular expressions'
complete -c paccat -l binary -d 'Print binary files'
complete -c paccat -s X -l executable -d 'Filter results to executable files'
complete -c paccat -s e -l extract -d 'Extract matched files to the current directory'
complete -c paccat -s i -l install -d 'Install matched files to the system'
complete -c paccat -s l -l list -d 'Print file names instead of file content'
complete -c paccat -l debug -d 'Display debug messages'
complete -c paccat -s h -l help -d 'Print help'
complete -c paccat -s V -l version -d 'Print version'
